Properties Methods Events Config Options Direct Link

# Class Ext.ensible.cal.MonthViewTemplate

Package: | Ext.ensible.cal
Defined In: | MonthViewTemplate.js
Class: | MonthViewTemplate
Extends: | Object

This is the template used to render the MonthView. Internally this class defers to an instance of Ext.calerndar.BoxLayoutTemplate to handle the inner layout rendering and adds containing elements around that to form the month view.

This template is automatically bound to the underlying event store by the calendar components and expects records of type Ext.ensible.cal.EventRecord.

## Config Options

Config Options | Defined By
--- | ---
| dayHeaderFormat : String The date format to use for day headers, if used (defaults to 'D', e.g. 'Mon' for Monday) | MonthViewTemplate
| dayHeaderTitleFormat : String The date format to use for the day header's HTML title attribute displayed on mouseover (defaults to 'l, F j, Y', e... The date format to use for the day header's HTML title attribute displayed on mouseover (defaults to 'l, F j, Y', e.g. 'Monday, December 27, 2010') | MonthViewTemplate

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.